---
name: Enhancement proposal
about: Propose an improvement to blackjax.
title: ''
labels: ''
assignees: ''
---

<!--
Before suggesting an improvement, please make sure this hasn't already been suggested by searching through the past issues and the PR tracker.
-->

### Current behavior

<!--
What behavior of the library made you think about the improvement?
-->

```python
Sample code with the current behavior
```

### Desired behavior

<!--
How would you like it to behave?
-->

```python
Sample code with the desired behavior
```

<!--
Be mindful that your proposal may be challenged. Blackjax has strong design principles that we are committed to stick to. If there is an alternative way to achieve what you would like, we will let you know.
-->
